Index: include/v8.h |
=================================================================== |
--- include/v8.h (revision 16081) |
+++ include/v8.h (working copy) |
@@ -1260,13 +1260,13 @@ |
class V8EXPORT JSON { |
public: |
/** |
* Tries to parse the string |json_string| and returns it as object if |
* successful. |
* |
* \param json_string The string to parse. |
* \return The corresponding object if successfully parsed. |
*/ |
- static Local<Object> Parse(Local<String> json_string); |
+ static Local<Value> Parse(Local<String> json_string); |
}; |
@@ -1260,13 +1260,13 @@ |
public: |
/** |
- * Tries to parse the string |json_string| and returns it as object if |
+ * Tries to parse the string |json_string| and returns it as value if |
* successful. |
* |
@@ -1260,13 +1260,13 @@ |
* |
* \param json_string The string to parse. |
- * \return The corresponding object if successfully parsed. |
+ * \return The corresponding value if successfully parsed. |
*/ |